==> haskell-hosc-0.18-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hosc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hosc
version:              0.18
visibility:           public
id:                   hosc-0.18-Dz2xs5GVTBX1J9owIIyt1v
key:                  hosc-0.18-Dz2xs5GVTBX1J9owIIyt1v
license:              GPL-3.0-only
copyright:            (c) Rohan Drape, Stefan Kersten and others, 2007-2020
maintainer:           rd@rohandrape.net
author:               Rohan Drape, Stefan Kersten
stability:            Experimental
homepage:             http://rohandrape.net/t/hosc
synopsis:             Haskell Open Sound Control
description:
    @hosc@ implements a subset of the Open Sound Control
    byte protocol, <http://opensoundcontrol.org/>.

    See "Sound.OSC.Core" or "Sound.OSC" or "Sound.OSC.FD".

category:             Sound
abi:                  2e7c9815f66499bfdc746693a4256b6f
exposed:              True
exposed-modules:
    Sound.OSC Sound.OSC.Coding.Byte Sound.OSC.Coding.Cast
    Sound.OSC.Coding.Convert Sound.OSC.Coding.Decode.Base
    Sound.OSC.Coding.Decode.Binary Sound.OSC.Coding.Encode.Base
    Sound.OSC.Coding.Encode.Builder Sound.OSC.Core Sound.OSC.Datum
    Sound.OSC.FD Sound.OSC.Packet Sound.OSC.Time Sound.OSC.Transport.FD
    Sound.OSC.Transport.FD.TCP Sound.OSC.Transport.FD.UDP
    Sound.OSC.Transport.Monad Sound.OSC.Wait

import-dirs:          /usr/lib/ghc-8.10.2/site-local/hosc-0.18
library-dirs:         /usr/lib/ghc-8.10.2/site-local/hosc-0.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/hosc-0.18
hs-libraries:         HShosc-0.18-Dz2xs5GVTBX1J9owIIyt1v
depends:
    base-4.14.1.0 binary-0.8.8.0
    blaze-builder-0.4.1.0-G4KXEZbDrFS6c5MmayHGI7 bytestring-0.10.10.0
    data-binary-ieee754-0.4.4-HlSlHq1qDaTKAKUZNW5rdz
    network-3.1.2.0-JIKweJluHA48N0sucYbDng time-1.9.3
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hosc/html/hosc.haddock
haddock-html:         /usr/share/doc/haskell-hosc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hosc-0.18-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hosc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hosc
version:              0.18
visibility:           public
id:                   hosc-0.18-NkY0zRY2Hn9Q4MIAKvv8v
key:                  hosc-0.18-NkY0zRY2Hn9Q4MIAKvv8v
license:              GPL-3.0-only
copyright:            (c) Rohan Drape, Stefan Kersten and others, 2007-2020
maintainer:           rd@rohandrape.net
author:               Rohan Drape, Stefan Kersten
stability:            Experimental
homepage:             http://rohandrape.net/t/hosc
synopsis:             Haskell Open Sound Control
description:
    @hosc@ implements a subset of the Open Sound Control
    byte protocol, <http://opensoundcontrol.org/>.

    See "Sound.OSC.Core" or "Sound.OSC" or "Sound.OSC.FD".

category:             Sound
abi:                  5faa5418b9218bd3ed4d403ea6930462
exposed:              True
exposed-modules:
    Sound.OSC Sound.OSC.Coding.Byte Sound.OSC.Coding.Cast
    Sound.OSC.Coding.Convert Sound.OSC.Coding.Decode.Base
    Sound.OSC.Coding.Decode.Binary Sound.OSC.Coding.Encode.Base
    Sound.OSC.Coding.Encode.Builder Sound.OSC.Core Sound.OSC.Datum
    Sound.OSC.FD Sound.OSC.Packet Sound.OSC.Time Sound.OSC.Transport.FD
    Sound.OSC.Transport.FD.TCP Sound.OSC.Transport.FD.UDP
    Sound.OSC.Transport.Monad Sound.OSC.Wait

import-dirs:          /usr/lib/ghc-8.10.2/site-local/hosc-0.18
library-dirs:         /usr/lib/ghc-8.10.2/site-local/hosc-0.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/hosc-0.18
hs-libraries:         HShosc-0.18-NkY0zRY2Hn9Q4MIAKvv8v
depends:
    base-4.14.1.0 binary-0.8.8.0
    blaze-builder-0.4.1.0-G4KXEZbDrFS6c5MmayHGI7 bytestring-0.10.10.0
    data-binary-ieee754-0.4.4-HlSlHq1qDaTKAKUZNW5rdz
    network-3.1.2.0-7C11VX86H1A7hyAq9JvH2M time-1.9.3
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hosc/html/hosc.haddock
haddock-html:         /usr/share/doc/haskell-hosc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
